@@ -17,7 +17,6 @@ use Froody::Response::Error;
 
 use HTTP::Request::Common;
 use LWP::UserAgent;
-use Encode qw(encode_utf8);
 my $ua = LWP::UserAgent->new;
 
 sub invoke
@@ -32,34 +31,31 @@ sub invoke
   for my $key (keys %$params) {
     my $arg_data = $method->arguments->{$key};
     my $value = delete $params->{$key};
-    # HTTP::Request::Common doesn't like undef
-    $value = '' unless defined $value;
-    no warnings 'uninitialized';
-    if ($arg_data->{type}[0] eq 'multipart') {
-      if (ref($value) eq 'ARRAY' and ref($value->[0])) {
-        $value = $value->[0];
-      }
+
+    next unless $arg_data;
+
+    if ($arg_data->{usertype} eq 'multipart') {
       $multi ||= 1;
-      if (UNIVERSAL::isa($value, "Froody::Upload")) {
-        $value = [ $value->filename, $value->client_filename ];
-      } elsif (!ref($value)) {
-        $value = [$value];
-      }
-    } elsif ($arg_data->{type}[0] eq 'csv' and ref($value) eq 'ARRAY') {
-      $value = join(",", @$value);
+      $value = [$value] unless ref $value;
     }
-    $params->{ encode_utf8( $key ) } = ref $value ? $value : encode_utf8($value);
+    $params->{$key} = $value;
   }
   $params->{method} = $method->full_name; 
 
   # Create a request
-  my $req = POST $uri, 
-    Content_Type => 'form-data',
-    Content => [ %$params ];
-  my $res = $ua->request($req);
+  my $req;
+  if ($multi) {
+    $req = POST $uri, 
+                Content_Type => 'form-data',
+                Content => [ %$params ];
+  } else {
+    $uri->query_form( %$params );
+    $req = GET $uri; 
+  }
+  my $res =$ua->request($req);
 
   unless ($res->is_success) {  
-    Froody::Error->throw("froody.invoke.remote", "Bad response from remote server - ". $res->status_line); 
+    Froody::Error->throw("froody.invoke.remote", "Bad response from remote server"); 
   }
 
   # return whatever we got
@@ -69,10 +65,6 @@ sub invoke
   return $frs;
 }
 
-sub source {
-  shift->url;
-}
-
 =head1 NAME
 
 Froody::Invoker::Remote - invoker that calls methods remotely
@@ -103,10 +95,6 @@ An Invoker that calls a remote server to get the Froody::Response.
 
 The URL of the REST endpoint.
 
-=item source
-
-Returns where this invoker originated
-
 =back
 
 =head1 BUGS
