@@ -84,19 +84,11 @@ sub xml
 sub render
 {
   my $self = shift;
-  my $output = $self->xml->toString(@_);
-  if ($XML::LibXML::VERSION < 1.63) {
-    $output = encode_utf8( $output );
-  }
-  return $output;
+  my $string = $self->xml->toString;
+  my $encoded = Encode::encode("utf-8", $string);
+  return $encoded;
 }
 
-# status is documented
-sub status
-{
-  my $self = shift;
-  $self->xml->findvalue('/rsp/@stat');
-}
 =head2 Converting other Responses to Froody::Response::XML objects
 
 Once you've loaded this class you can automatically convert other
@@ -122,13 +114,11 @@ sub Froody::Response::as_xml
   my $self = shift;
   
   my $parser = XML::LibXML->new();
-  my $rendered = $self->render
-    or Froody::Error->throw('froody.invoke.badresponse', "No XML returned from call");
-  my $doc = eval { $parser->parse_string($rendered) } or die "$rendered";
+  my $doc = $parser->parse_string($self->render);
   
   my $xml = Froody::Response::XML->new();
   $xml->xml($doc);
-  $xml->structure($self->structure) if $self->structure;
+  $xml->structure($self->structure);
 
   return $xml;
 }
