@@ -34,92 +34,35 @@ use strict;
 use warnings;
 
 use HTTP::Date;
-use Froody::Request::CGI;
-use Froody::Dispatch;
-
-use Froody::Server;
 
 sub handle_request
 {
-  my ($self, $cgi) = @_;
-
-  $self->dispatcher->error_style("response");
-
-  my $response;
-
-  # what are we asking for?
-  my $request = eval { Froody::Request::CGI->new($cgi) };
-  if ($@) {
-    if ($@ =~ /does not map to Unicode/) {
-      # CGI / apache params were not unicode
-      my $e = $@;
-      my $dispatcher = $self->dispatcher;
-      $response = $dispatcher->error_class->from_exception(
-        Froody::Error->new('perl.methodcall.param', 'Some paramaters were not valid utf8'),
-        $dispatcher->repository
-      );
-
-    } else {
-      # some other error
-      Carp::confess($@);
-    }
-  } else {
-    $response = eval { $self->dispatcher->dispatch(
-        method => $request->method,
-        params => $request->params || {},
-    ) };
-    if ($@) {
-      $self->_send_bytes("500 Server Error", "text/plain", "$@");
-      return;
-    }
-  }
-
-  my $type = $request ? $request->type : 'xml';
-  # send the data back to the browser
-  my $method = "render_$type";
-  $response->callback( $request->callback ) if $request;
-  return $self->_send_bytes(
-    "200 OK",
-    Froody::Server->content_type_for_type($type), 
-    $response->$method
-  );
-}
-
-=head2 config
-
-=cut
-
-sub config {
-    my $self = shift;
-    $self->{_dispatcher} = Froody::Dispatch->config(@_);
-}
-
-=head2 dispatcher
-
-=cut
-
-sub dispatcher {
-  my $self = shift;
-  if (@_) {
-    $self->{_dispatcher} = shift;
-    return $self;
-  }
-  return $self->{_dispatcher} ||= Froody::Dispatch->new;
+ my ($self, $cgi) = @_;
+ 
+  use Froody::Request::CGI;
+  my $request = Froody::Request::CGI->new();
+  
+  use Froody::Dispatch;
+  our $dispatcher ||= Froody::Dispatch->new();
+  $dispatcher->error_style("response");
+  $self->_send_bytes($dispatcher->dispatch(
+    method => $request->method,
+    params => $request->params,
+  )->present);
 }
 
 sub _send_bytes
 {
   my $self = shift;
-  my $status = shift;
-  my $content_type = shift;
   my $bytes = shift;
+  
   my $time = time2str();
   
   # server headers
-  print "HTTP/1.0 $status\r\n";
+  print "HTTP/1.0 200 OK\r\n";
 
   # standard headers
-  print "Content-Type: $content_type\r\n";
+  print "Content-Type: text/xml\r\n";
   print "Content-Length: ", length($bytes), "\r\n";
 
   # froody headers (for debugging)
@@ -136,7 +79,6 @@ sub _send_bytes
  
   # content
   print $bytes;
-  return;
 }
 
 =head1 BUGS
